|
Native (oversimplified) Julia gemm implementation
|
|
6
|
1305
|
August 15, 2019
|
|
Relative performance discrepancy across cpus even with --cpu-target set
|
|
5
|
1124
|
August 14, 2019
|
|
How to speed up a generic function evaluating multiple array calculations
|
|
3
|
839
|
August 13, 2019
|
|
Segfault with SIMD.jl and BenchmarkTools.jl
|
|
6
|
631
|
August 10, 2019
|
|
Simple tutorial for PackageCompiler sysimage build?
|
|
0
|
398
|
August 9, 2019
|
|
Efficiently traverse binary tree represented as tuple of tuples
|
|
9
|
2097
|
August 7, 2019
|
|
Calculate SVM dual loss effeciently
|
|
0
|
523
|
August 5, 2019
|
|
Unexpected 4x slowdown when computing many svds in loop
|
|
4
|
790
|
August 4, 2019
|
|
Allocations in mapreduce/sum etc
|
|
2
|
1137
|
August 1, 2019
|
|
How efficient is dictionary lookup in Julia?
|
|
6
|
5304
|
July 30, 2019
|
|
What is the memory overhead of a mutable struct?
|
|
8
|
2371
|
July 30, 2019
|
|
Unusual slow Julia code compared to C++?
|
|
21
|
4887
|
July 30, 2019
|
|
Filling a preallocated array without allocations
|
|
7
|
2189
|
July 29, 2019
|
|
Dot equals .=
|
|
3
|
4810
|
July 26, 2019
|
|
Vector{Float} times Vector{Complex} slower than Vector{Complex} times Vector{Complex}
|
|
6
|
685
|
July 26, 2019
|
|
How to access shared "inherited" fields without paying multiple dispatch performance price?
|
|
14
|
1649
|
July 25, 2019
|
|
How to use SIMD with a very simple example
|
|
6
|
2274
|
July 23, 2019
|
|
Ways to make slow/sluggish REPL/interactive development experience faster?
|
|
35
|
6136
|
July 23, 2019
|
|
Split an Int128 to two Int64
|
|
2
|
2365
|
July 22, 2019
|
|
Puzzled by the difference in performance when summing an array in different ways
|
|
4
|
976
|
July 19, 2019
|
|
Fluctuations when measuring execution time of linear algebra code
|
|
12
|
1265
|
July 19, 2019
|
|
Indexing multidimensional arrays of arbitrary dimension
|
|
11
|
1807
|
June 26, 2019
|
|
Bad performance using DistributedArray SPMD for 1D diffusion problem
|
|
2
|
881
|
July 18, 2019
|
|
Modules VS Passing arguments to functions
|
|
5
|
1617
|
July 18, 2019
|
|
New behaviour due to an update of the package CSV when using CSV.write
|
|
7
|
1358
|
July 17, 2019
|
|
Strange allocation
|
|
2
|
438
|
July 17, 2019
|
|
Unusually bad performance of eigen() compared to eig() in Matlab
|
|
16
|
3473
|
July 17, 2019
|
|
Speed of dispatch with heterogeneous functions and types
|
|
10
|
1131
|
July 16, 2019
|
|
Seemingly unnecessary code cruft in a compiled higher-order function
|
|
9
|
851
|
July 15, 2019
|
|
Dispatch on Value allocating
|
|
9
|
1870
|
July 14, 2019
|